Frequently Asked Questions
--------------------------

This page would be populated with common questions the authors have been asked about tiote

`No use of foriegn keys`
	It takes a high amout of database queries to generate all the needed data for a single column to a single table needed foreign relations. This would then increase polynomially for all the columns in a table. Therefore automation and editing of foreign key relations are disabled
